/*
CandleColor.mq4
 2009 Eugene Logunov (lea)
*/
#property copyright " 2009 Eugene Logunov (lea)"

/***************************************************************************************/

// indicator display settings
#property indicator_separate_window
#property indicator_minimum -1.25
#property indicator_maximum 1.25
#property indicator_buffers 3
#property indicator_color1 Blue
#property indicator_color2 Red
#property indicator_color3 Green

/***************************************************************************************/

// defining the possible candlestick directions
#define DIRECTION_NONE 0
#define DIRECTION_UP 1
#define DIRECTION_DOWN -1

/***************************************************************************************/

// period of the simple moving average based on the data on directions
extern int period=15;

/***************************************************************************************/

// histograms of candlestick directions
double bufDirHistUp[];
double bufDirHistDown[];
// moving average based on candlestick directions
double bufDirSoft[];
// buffer for the series of candlestick directions
double bufDir[];

/***************************************************************************************/

// getting the candlestick direction
double GetCandleDirection(int shift) {
   double diff=Close[shift]-Open[shift];
   if (diff>0.0) {
      return (DIRECTION_UP);
   }
   else if (diff<0.0) {
      return (DIRECTION_DOWN);
   }
   else /*if (diff==0.0)*/ {
      return (DIRECTION_NONE);
   }
}

/***************************************************************************************/

int init() {
   // the indicator uses 1 additional buffer for calculations
   IndicatorBuffers(4);
   // set drawing styles for buffers
   SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexStyle(2,DRAW_LINE);
   // bind buffers
   SetIndexBuffer(0,bufDirHistUp);
   SetIndexBuffer(1,bufDirHistDown);
   SetIndexBuffer(2,bufDirSoft);
   SetIndexBuffer(3,bufDir);
   return (0);
}

int start() {
   int limit=MathMax(1,MathMin(Bars-1,Bars-IndicatorCounted()+1));
   // determine candlestick directions; break them down into 2 histograms
   for (int shift=limit;shift>=0;shift--) {
      bufDir[shift]=GetCandleDirection(shift);
      bufDirHistUp[shift]=MathMax(0,bufDir[shift]);
      bufDirHistDown[shift]=MathMin(0,bufDir[shift]);
   }
   limit=MathMax(limit-period,0);
   // calculate the moving average based on the buffer of candlestick directions
   for (shift=limit;shift>=0;shift--) {
      bufDirSoft[shift]=iMAOnArray(bufDir,0,period,0,MODE_SMA,shift);
   }
   return (0);
}

